package com.miaxis.app.controller.gan;

import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.utils.DateUtils;
import com.miaxis.disease.domain.DiseasePart;
import com.miaxis.gan.dto.GanZhiDto;
import com.miaxis.gan.dto.LiuNianDto;
import com.miaxis.gan.service.IGanZhiService;
import com.miaxis.gan.vo.*;
import com.nlf.calendar.Lunar;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

/**
 * 【天干地支】Controller
 *
 * @author miaxis
 * @date 2023-11-16
 */
@RestController
@RequestMapping(Constants.OPEN_PREFIX + "/gan/zhi")
@Api(tags = {"【app-天干地支】"})
public class GanZhiController extends BaseController {
    @Autowired
    private IGanZhiService ganZhiService;


    /**
     * 查询天干地支列表

     @GetMapping("/list")
     @ApiOperation("查询天干地支列表")
     @ApiImplicitParams({
     @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
     @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
     })
     public ResponsePageInfo<GanZhi> list(@ModelAttribute GanZhi ganZhi) {
     startPage();
     List<GanZhi> list = ganZhiService.selectGanZhiList(ganZhi);
     return toResponsePageInfo(list);
     }
     */

    /**
     * 查询天干地支列表
     */
    @GetMapping("/get8ziByDate")
    @ApiOperation("干支查询8字")
    public Response<GanZhiVo> get8ziByDate(@ModelAttribute GanZhiDto ganZhiDto) {

        Map<String, String> reportMap = new TreeMap<String, String>();


        Date birthDay = ganZhiDto.getBirthDay();
        Lunar lunar = Lunar.fromDate(birthDay);
        GanZhiDaYunVo ganZhiDaYunVo = new GanZhiDaYunVo();
        ganZhiDaYunVo.setLunar(lunar);
        System.out.println("农历：" + lunar.getYear() + "年(生肖" + lunar.getYearShengXiao() + ")" + lunar.getMonth() + "月" + lunar.getDay() + "日" + lunar.getTime() + "时");


        System.out.println(lunar.getYear());   //年
        System.out.println(lunar.getMonth());   //月
        System.out.println(lunar.getDay());     //日
        String time = lunar.getTime().toString().substring(lunar.getTime().toString().length() - 1); //时
        System.out.println(time);


        // 获取干支纪年
        ganZhiDto.setYearGan(lunar.getYearGan());
        ganZhiDto.setYearZhi(lunar.getYearZhi());

        ganZhiDto.setMonthGan(lunar.getMonthGan());
        ganZhiDto.setMonthZhi(lunar.getMonthZhi());

        ganZhiDto.setDayGan(lunar.getDayGan());
        ganZhiDto.setDayZhi(lunar.getDayZhi());

        ganZhiDto.setTimeGan(lunar.getTimeGan());
        ganZhiDto.setTimeZhi(lunar.getTimeZhi());

        ganZhiDaYunVo = ganZhiService.getDaYun(ganZhiDto, ganZhiDaYunVo); //月柱节气矫正 取出90年大运
        List<GanZhiRowVo> ganZhiRowVoList = ganZhiService.selectGanZhiRowVoList(ganZhiDto); //拼装
        Map<String, Integer> fiveCountMap = ganZhiService.getGanZhiRowVoCount(ganZhiRowVoList, reportMap); //五行数量
        Map<String, Object> riYuanQrMap = ganZhiService.getRiYuanQr(ganZhiRowVoList, fiveCountMap);  //查出日元强弱
        String xifangWei = ganZhiService.getXiFangWei(ganZhiDaYunVo.getLunar()); //喜用的方位
        Map<String, String> chenGuMap = ganZhiService.getChenGu(ganZhiDaYunVo.getLunar(), ganZhiDto.getSex());


        String guiren = ganZhiService.getGuiren(ganZhiRowVoList);  //贵人

        int maxTianGan = ganZhiService.getMaxTianGan(ganZhiDto);  //最出能量最强的天干
        Map<String, String> geJuMap = ganZhiService.getGeJu(ganZhiRowVoList, maxTianGan, riYuanQrMap.get("qr").toString()); //查出八字常见格局
        String geju = geJuMap.get("geju");

        String industry = ganZhiService.getIndustry(riYuanQrMap, geju); //行业

        Map<Integer, String> guoGuanMap = ganZhiService.getGuo3Guan(ganZhiRowVoList, riYuanQrMap.get("qr").toString()); //过三关


        Map<String, Integer> shiShenCountMap = ganZhiService.getShiShenCount(ganZhiRowVoList, reportMap);
        List<GanZhiNaYinVo> ganZhiNaYinVoList = ganZhiService.selectGanZhiNaYinList(ganZhiDto);
        List<GanZhiKongWangVo> ganZhiKongWangVoList = ganZhiService.selectGanZhiKongWangList(ganZhiDto);
        Map<String, Object> numberYunMap = ganZhiService.getNumberYun(riYuanQrMap);  //喜用数字
        Map<String, Integer> zaoShiCount = ganZhiService.getZaoShiCount(ganZhiRowVoList, fiveCountMap, reportMap);
        List<DiseasePart> diseasePartList = ganZhiService.getJiBing(ganZhiRowVoList, fiveCountMap);

        String caiYun = ganZhiService.getCaiYun(ganZhiRowVoList, riYuanQrMap, shiShenCountMap);

        String piQi = ganZhiService.getPiQi(ganZhiRowVoList); //脾气

        GanZhiVo ganZhiVo = new GanZhiVo();
        ganZhiVo.setNongDay(lunar.getYear() + "年(生肖" + lunar.getYearShengXiao() + ")" + lunar.getMonth() + "月" + lunar.getDay() + "日" + lunar.getTime() + "时");
        ganZhiVo.setBirthDay(ganZhiDto.getBirthDay());
        ganZhiVo.setGanZhiRowVoList(ganZhiRowVoList);
        ganZhiVo.setFiveCountMap(fiveCountMap);
        ganZhiVo.setShiShenCountMap(shiShenCountMap);
        ganZhiVo.setGanZhiNaYinVoList(ganZhiNaYinVoList);
        ganZhiVo.setGanZhiKongWangVoList(ganZhiKongWangVoList);

        ganZhiVo.setUsername(ganZhiDto.getUsername());
        ganZhiVo.setSex(ganZhiDto.getSex());
        ganZhiVo.setRiYuan(riYuanQrMap);
        ganZhiVo.setNumberYunMap(numberYunMap);
        ganZhiVo.setZaoShiMap(zaoShiCount);
        ganZhiVo.setDiseasePartList(diseasePartList);
        ganZhiVo.setDaYunList(ganZhiDaYunVo.getDaYunList());
        ganZhiVo.setGeJuMap(geJuMap);
        ganZhiVo.setGuoGuanMap(guoGuanMap);
        ganZhiVo.setXiFangWei(xifangWei);
        ganZhiVo.setIndustry(industry);
        ganZhiVo.setGuiren(guiren);
        ganZhiVo.setChenGuMap(chenGuMap);
        ganZhiVo.setPiQi(piQi);

        reportMap.put("财运",caiYun);
        ganZhiVo.setReportMap(reportMap);


        // 输出结果
        return Response.success(ganZhiVo);
    }


    /**
     * 输入大运时间返回流年
     */
    @GetMapping("/getLiuNian")
    @ApiOperation("输入大运时间返回流年")
    public Response<List<Map<String, String>>> getLiuNian(@ModelAttribute LiuNianDto liuNianDto) {

        List<Map<String, String>> liuNianList = ganZhiService.getLiuNian(liuNianDto);

        // 输出结果
        return Response.success(liuNianList);
    }


}
